/*-----------------------------------------------------------------------------------+
|                              Interrupt Accessor                                    |
|                                                                                    |
| Name: Interrupt.c                                                                  |
| Purpose:                                                                           |
|    provide the function for easier access the interrupt, or timer setting.         |
|                                                                                    |
+-----------------------------------------------------------------------------------*/

/*___________ I N C L U D E S ______________________________________________________*/

#include <reg51.h>
#include <stdio.h>
#include "InterruptConfig.h"


/*___________ B A U D   R A T E   9 6 0 0  ___________________________________________*/


// com port with 9600 baud with crystal 11.0592MHz.
void init_uart(void)
{
	SCON  = 0x50;		        
    TMOD |= 0x20;               
    TH1   = 253;                
    TR1   = 1;                 
    TI    = 1; 
}


/*___________ T I M E R 0 ____________________________________________________________*/


// initalize 16 bits timer0, with time interval equal 0.05s
void init_Timer0(void)	
{
	TMOD |=	0x01;			// set time0 as mode0
	TH0=(65536-46079)/256;	// count 46080 machine cycle
	TL0=(65536-46079)%256;	// 1 machine cycle = 12/11.0598M = 1.085us
	IE |=0x82;				// 46080x1.085u=0.05s
	TR0=1;
}

// turn on timer0
void turnOnTimer0(void)
{
	TR0=1;
}

// turn off timer0
void turnOffTimer0(void)
{
	TR0=0;
}

// check whether timer 0 is on or off. ON return 1, OFF return 0;
bit isTimer0ON(void)
{
	if(TR0)
		return 1;
	else
		return 0;
}


/*___________ I N T E R R U P T  _____________________________________________________*/


// initalize external interrupt 0 (P3.2)
void init_int0(void)
{
	PX0=1; 		//Define Int0 high priority
	IE0=0; 		//External Interrupt 0 edge flag, set when external interrupt 
				//detected,cleared when interrupt is processed.
	IT0=1; 		//set to specific falling edge produce interrupt
	EX0=1; 		//enable External Interrupt 0
	EA=1; 		//enable all interrupt
}

// enable external interrupt 0
void enINT0(void)
{
	EX0=1;
}

// disable external interrupt 0
void disINT0(void)
{
	EX0=0;
}
