/*----------------------------------------------------------------------------------+
|                                                                                   |
| Name: TaskSharing.c                                                               |
| Purpose:                                                                          |
|		The c files provde the functions to implement the multitasking jobs, 1-8    |
|       Each 50ms will execute the 1 job, therefore for job 1 to execute again. It  |
|       is required to wait 7 jobs complete, that is 7x50ms.                        |
| Example:                                                                          |
|       50ms , 50ms , 50ms , 50ms , 50ms , 50ms , 50ms , 50ms , 50ms                |
|         ^      ^      ^      ^      ^      ^      ^      ^      ^                 |    
|       job1   job2   job3   job4   job5   job6   job7   job8   job1  ..... again.. |
+----------------------------------------------------------------------------------*/

/*___________ I N C L U D E S ______________________________________________________*/

#include <reg51.h>
#include <stdio.h>
#include "InterruptConfig.h"

/*___________ I N T E R R U P T   R O U N T I N E S___________________________________*/

/*
	when external interrupt occur, count will increase 1 and toggle P1
*/
void ExInt(void) interrupt 0
{
	printf("\nExternal Interrupt occur");
}


/*
	when timer0 time up 50ms, execute  the code. 
*/
void timer0_ISR (void) interrupt 1 
{
	static task_index;
	TH0=(65536-46079)/256; // count 46080 machine cycle
	TL0=(65536-46079)%256; // 1 machine cycle = 12/11.0598M = 1.085us
	switch(++task_index)
  	{
		 case 1 : printf("1"); break;
		 case 2 : printf("2"); break;
		 case 3 : printf("3"); break;
		 case 4 : printf("4"); break;
		 case 5 : printf("5"); break;
		 case 6 : printf("6"); break;
		 case 7 : printf("7"); break;
		 case 8 : printf("8"); task_index=0; break;
		 default : task_index=0;
	}
}
